@@ -6,23 +6,28 @@ use warnings;
 use Carp qw(croak);
 use English qw(-no_match_vars);
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
+
+my $maybe_set_subname = sub { $ARG[1]; };
 
 # Will be shipping with Perl 5.22
-my $NAME = eval {
+eval {
     require Sub::Util;
-    Sub::Util->can('set_subname');
-} || sub { $ARG[1] };
+
+    if (my $set_subname = Sub::Util->can('set_subname')) {
+        $maybe_set_subname = $set_subname;
+    }
+};
 
 sub attr {
     my ($self, $attr, %param) = @ARG;
 
     my $class = ref $self || $self;
 
-    croak qq{Class not defined\n}
+    croak q{Class not defined}
         unless defined $class and length $class;
 
-    croak qq{Attribute not defined\n}
+    croak q{Attribute not defined}
         unless defined $attr and length $attr;
 
     my %patch;
@@ -97,12 +102,24 @@ sub monkey_patch {
     while(my ($method_name, $value) = each %patch) {
         my $full_name = $class .q{::}. $method_name;
 
-        *{$full_name} = $NAME->($full_name, $value);
+        *{$full_name} = $maybe_set_subname->($full_name, $value);
     }
 
     return 1;
 }
 
+sub cleanup_namespace {
+    my @names  = @ARG;
+    my $caller = caller;
+
+    no strict 'refs';
+    my $ref = \%{ $caller .'::' };
+
+    map { delete $ref->{$_} } @names;
+
+    return 1;
+}
+
 sub import {
     my $caller = caller;
 
@@ -119,7 +136,7 @@ JIP::ClassField - Create attribute accessor for hash-based objects
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =head1 SYNOPSIS
 
@@ -151,6 +168,9 @@ Version 0.03
     }));
     is($self->set_qux->qux, 42);
 
+    JIP::ClassField::cleanup_namespace('has');
+    ok(not __PACKAGE__->can('has'));
+
     done_testing();
 
 =head1 SEE ALSO
